@@ -55,7 +55,6 @@ Converter::~Converter()
 void Converter::run()
 {
     m_process_stopped = 0;
-    m_conv_status = 2;  // Jumped
 
     Image my_image;
     QFileInfo fi(m_fileNameIn);
@@ -63,13 +62,27 @@ void Converter::run()
     QString err_read_status;
     QString err_write_status;
 
-    if (!m_overwrite)   // modalità sovrascrittura
+    // Skip existing files
+    if (m_overwrite == SKIP) {
+        if (skipExisting(out)) {
+            m_conv_status = 2;  // Skipped
+            QString skipMsg = QString(tr("Skipped: %1 already esists."))
+                                  .arg(fi.fileName());
+            emit errorMessage(skipMsg);
+
+            return;
+        }
+    }
+
+    // Overwrite existing files
+    if (m_overwrite == ASK)
         out = overwriteOldFileName(out);
 
     if (!m_process_stopped) {
         my_image.quiet(true);
         try {
             my_image.read(m_fileNameIn.toStdString());
+            my_image.autoOrient();
         } catch (Error &error) {
             m_conv_status = -1;
 
@@ -208,7 +221,7 @@ void Converter::setBackgroundColor(QString bg_color, bool changeBg_color)
     m_changeBg_color = changeBg_color;
 }
 
-void Converter::setOverwrite(bool overwrite)
+void Converter::setOverwrite(OverwriteMode overwrite)
 {
     m_overwrite = overwrite;
 }
@@ -219,7 +232,7 @@ QString Converter::overwriteOldFileName(QString out)
     m_newBaseName = fi.baseName();
 
     if (fi.exists()) {
-        if (!m_overwrite) {
+        if (m_overwrite == ASK) {
             emit requestOverwrite(m_newBaseName);
 
             mutex.lock();
@@ -232,6 +245,17 @@ QString Converter::overwriteOldFileName(QString out)
         return out;
 }
 
+bool Converter::skipExisting(QString out)
+{
+    QFileInfo fi(out);
+    m_newBaseName = fi.baseName();
+
+    if (fi.exists())
+        return true;
+    else
+        return false;
+}
+
 void Converter::setNewBasename(QString newBaseName, bool ok)
 {
     if (ok)
@@ -257,10 +281,19 @@ void Converter::setRemoveMetadata(const bool &value)
 
 bool Converter::writeImage(Image &my_image, const QString &format, const int &quality, const QString &out, QString &error_status)
 {
-    QString inputFormat = QString::fromLocal8Bit(my_image.magick().c_str());
+    bool is_writable = true;
 
-    Magick::CoderInfo formatCoderInfo(format.toUpper().toStdString());
-    bool is_writable = formatCoderInfo.isWritable();
+    // TODO: This will be fixed in 1.0 version :^)
+    if (format == "hif")
+        my_image.magick("HEIF");
+    else if (format == "jfif")
+        my_image.magick("JPEG");
+    else {
+        Magick::CoderInfo formatCoderInfo(format.toUpper().toStdString());
+        is_writable = formatCoderInfo.isWritable();
+
+        my_image.magick(format.toUpper().toStdString());
+    }
 
     if (!is_writable) {
         error_status = tr("ERROR: Format %1 is not supported for writing, choose another output format. Skipping!")
@@ -269,7 +302,7 @@ bool Converter::writeImage(Image &my_image, const QString &format, const int &qu
         return false;
     }
 
-    my_image.magick(format.toUpper().toStdString());
+    QString inputFormat = QString::fromLocal8Bit(my_image.magick().c_str());
 
     if (inputFormat == "PDF") {
         my_image = convertPDFtoImage(my_image);
