@@ -12,7 +12,7 @@ class DialogShowUpdateMsg : public QDialog
     Q_OBJECT
 
 public:
-    explicit DialogShowUpdateMsg(QWidget *parent = 0, const QString &caption = 0, const QString &message = 0);
+    explicit DialogShowUpdateMsg(QWidget *parent = 0, const QString &caption = 0, const QString &message = 0, const bool &isChecked = 0);
     ~DialogShowUpdateMsg();
 
 private slots:
