@@ -89,23 +89,31 @@ void Formats::loadFormats()
     s_readableFormattedFilters.removeAll("*.txt");
 
     // Add missing but supported formats
-    s_readableFormattedFilters.append(QStringList() <<  "*.tif" << "*.jfif");
+    s_readableFilters.append(QStringList() << "tif" << "jfif");
+    s_readableFormattedFilters.append(QStringList() << "*.tif" << "*.jfif");
 
     ////////////////////
     // Adding manually some missing but supported formats
     readableFiltersList << ";;Tagged Image File Format [*.tif] (*.tif *.TIF )";
     readableFiltersList << ";;Joint Photographic Experts Group JFIF format [*.jfif] (*.jfif *.JFIF )";
-    readableFiltersList = sortNonCaseSensitive(readableFiltersList);
-
     readableExts += "*.tif *.TIF *.jfif *.JFIF";
+    // Add hif format if heif is available
+    if (readableExts.contains("heif")) {
+        readableFiltersList << ";;High Efficiency Image Format [*.hif] (*.hif *.HIF )";
+        readableExts += "*.hif *.HIF";
+    }
     ////////////////////
 
+    /* Readable */
+    readableFiltersList = sortNonCaseSensitive(readableFiltersList);
     s_readableFiltersString = readableFiltersList.join("");
     s_readableFiltersString.prepend(tr("All Supported Filters (%1)").arg(readableExts));
 
     // Adding manually some missing but supported formats
     s_writableFilters << "TIF - (Tagged Image File Format)";
     s_writableFilters << "JFIF - (Joint Photographic Experts Group JFIF format)";
+    if (s_writableFilters.contains("HEIF - (High Efficiency Image Format)"))
+        s_writableFilters << "HIF - (High Efficiency Image Format)";
     s_writableFilters = sortNonCaseSensitive(s_writableFilters);
 
     s_writableFilters.prepend(tr("Don't change the format"));
